Crate signet_sim

Crate signet_sim 

Signet Sim

A simple parallelized transaction simulation library.

Structs

AcctInfo
Account information including nonce and balance. This is partially modeled after revm::AccountInfo, but only includes the fields we care about.
BlockBuild
Builds a single block by repeatedly invoking SimEnv.
BuiltBlock
A block that has been built by the simulator.
HostEnv
A host simulation environment.
ProviderStateSource
A wrapper that implements StateSource for any alloy Provider.
RollupEnv
A rollup simulation environment.
SharedSimEnv
A simulation environment.
SimCache
A cache for the simulator.
SimEnv
A simulation environment.
SimOutcomeWithCache
A simulation outcome that includes the score, gas used, and a cache of state changes.

Enums

CacheError
Possible errors that can occur when using the cache.
SimIdentifier
A simulation cache item identifier.
SimItem
An item that can be simulated, wrapped in an Arc for cheap cloning.
SimItemValidity
The validity status of a simulation item.

Traits

StateSource
A source for nonce and balance information. Exists to simplify type bounds in various places.

Functions

check_bundle_tx_list
Check a list of bundle transactions for validity against a state source.

Type Aliases

InnerDb
A type alias for the database underlying the simulation.
SimDb
A type alias for the database used in the simulation.
TimeLimited
A time-limited layered inspector.