pub enum SimItem {
Bundle(Arc<RecoveredBundle>),
Tx(Arc<Recovered<TxEnvelope>>),
}Expand description
An item that can be simulated, wrapped in an Arc for cheap cloning.
Variants
Bundle(Arc<RecoveredBundle>)
A bundle to be simulated.
Tx(Arc<Recovered<TxEnvelope>>)
A transaction to be simulated.
Implementations
Sourceimpl SimItem
impl SimItem
Sourcepub fn as_bundle(&self) -> Option<&RecoveredBundle>
pub fn as_bundle(&self) -> Option<&RecoveredBundle>
Get the bundle if it is a bundle.
Sourcepub fn as_tx(&self) -> Option<&Recovered<TxEnvelope>>
pub fn as_tx(&self) -> Option<&Recovered<TxEnvelope>>
Get the transaction if it is a transaction.
Sourcepub fn calculate_total_fee(&self, basefee: u64) -> u128
pub fn calculate_total_fee(&self, basefee: u64) -> u128
Calculate the maximum gas fee payable, this may be used as a heuristic to determine simulation order.
Sourceimpl SimItem
impl SimItem
Sourcepub fn identifier(&self) -> SimIdentifier<'_>
pub fn identifier(&self) -> SimIdentifier<'_>
Returns a unique identifier for this item, which can be used to distinguish it from other items.
Sourcepub fn identifier_owned(&self) -> SimIdentifier<'static>
pub fn identifier_owned(&self) -> SimIdentifier<'static>
Returns an unique, owned identifier for this item.
Sourcepub async fn check<S, S2>(
&self,
source: &S,
host_source: &S2,
) -> Result<SimItemValidity, Box<dyn Error>>where
S: StateSource,
S2: StateSource,
pub async fn check<S, S2>(
&self,
source: &S,
host_source: &S2,
) -> Result<SimItemValidity, Box<dyn Error>>where
S: StateSource,
S2: StateSource,
Check if the item is valid against the provided state sources.
This will check that nonces and balances are sufficient for the item to be included on the current state.