SimItemValidity

Enum SimItemValidity 

pub enum SimItemValidity {
    Never,
    Future,
    Now,
}
The validity status of a simulation item.

These are ordered from least to most valid. An item that is Never valid is always invalid, an item that is Future valid may become valid in the future, and an item that is Now valid is currently valid.

Variants



Never

The item is invalid and should not be simulated.



Future

The item is currently invalid, but may become valid in the future.

For example, this may be due to nonce gaps.



Now

The item is valid and can be simulated.

Implementations

Source

impl SimItemValidity

pub const fn is_valid_now(&self) -> bool

Returns true if the item is valid now.

pub const fn is_never_valid(&self) -> bool

Returns true if the item is never valid.

pub const fn is_future_valid(&self) -> bool

Returns true if the item may be valid in the future.