BlockBuild

Struct BlockBuild 

pub struct BlockBuild<RuDb, HostDb, RuAsync, HostAsync, RuInsp = NoOpInspector, HostInsp = NoOpInspector> { /* private fields */ }
Builds a single block by repeatedly invoking SimEnv.

Implementations

Source

impl<RuDb, HostDb, RuAsync, HostAsync, RuInsp, HostInsp> BlockBuild<RuDb, HostDb, RuAsync, HostAsync, RuInsp, HostInsp>
where RuDb: DatabaseRef + Send + Sync + 'static, RuInsp: Inspector<Ctx<SimDb<RuDb>>> + Default + Sync + 'static, HostDb: DatabaseRef + Send + Sync + 'static, HostInsp: Inspector<Ctx<SimDb<HostDb>>> + Default + Sync + 'static, RuAsync: StateSource, HostAsync: StateSource,

pub fn new( rollup: RollupEnv<RuDb, RuInsp>, host: HostEnv<HostDb, HostInsp>, finish_by: Instant, concurrency_limit: usize, sim_items: SimCache, max_gas: u64, max_host_gas: u64, ru_async_source: RuAsync, host_async_source: HostAsync, ) -> Self

Create a new block building process.

pub const fn max_gas(&self) -> u64

Get the maximum gas limit for the block being built.

pub const fn set_max_gas(&mut self, max_gas: u64)

Set the maximum gas limit for the block being built.

pub const fn max_host_gas(&self) -> u64

Get the maximum host gas limit for the block being built.

pub const fn set_max_host_gas(&mut self, max_host_gas: u64)

Set the maximum host gas limit for the block being built.

pub fn sim_items(&self) -> &SimCache

Get a reference the simulation cache used by this builder.

pub fn rollup_env(&self) -> &RollupEnv<RuDb, RuInsp>

Get a reference to the rollup environment.

pub fn host_env(&self) -> &HostEnv<HostDb, HostInsp>

Get a reference to the host environment.

pub fn into_block(self) -> BuiltBlock

Consume the builder and return the built block.

This should generally not be called directly; use BlockBuild::build instead.

pub async fn run_build(self) -> Self

Run several rounds, building a block by iteratively adding simulated items.

This version returns self to allow inspection of the building process. It does nothing if the block already has transactions (i.e. this function should be idempotent).

pub async fn build(self) -> BuiltBlock

Run several rounds, building a block by iteratively adding simulated items.