pub struct BuiltBlock { /* private fields */ }Expand description
A block that has been built by the simulator.
Implementations
Sourceimpl BuiltBlock
impl BuiltBlock
Sourcepub const fn block_number(&self) -> u64
pub const fn block_number(&self) -> u64
Gets the block number for the block.
Sourcepub fn transactions(&self) -> &[TxEnvelope] ⓘ
pub fn transactions(&self) -> &[TxEnvelope] ⓘ
Get the current list of transactions included in this block.
Sourcepub fn host_fills(&self) -> &[SignedFill]
pub fn host_fills(&self) -> &[SignedFill]
Get the current list of host fills included in this block.
Sourcepub fn ingest_tx(&mut self, tx: TxEnvelope)
pub fn ingest_tx(&mut self, tx: TxEnvelope)
Ingest a transaction into the in-progress block.
Sourcepub fn ingest_bundle(&mut self, bundle: SignetEthBundle)
pub fn ingest_bundle(&mut self, bundle: SignetEthBundle)
Ingest a bundle into the in-progress block. Ignores Signed Orders for now.
Sourcepub fn contents_hash(&self) -> &B256
pub fn contents_hash(&self) -> &B256
Calculate the hash of the in-progress block, finishing the block.
Sourcepub fn encode_calldata(&self) -> &Bytes
pub fn encode_calldata(&self) -> &Bytes
Convert the in-progress block to sign request contents.
Sourcepub fn encode_blob<T: SidecarCoder + Default>(&self) -> SidecarBuilder<T>
pub fn encode_blob<T: SidecarCoder + Default>(&self) -> SidecarBuilder<T>
Convert the in-progress block to a blob transaction sidecar.