SimCache

Struct SimCache 

pub struct SimCache { /* private fields */ }
A cache for the simulator.

This cache is used to store the items that are being simulated.

Implementations

Source

impl SimCache

pub fn new() -> Self

Create a new SimCache instance, with a default capacity of 100.

pub fn with_capacity(capacity: usize) -> Self

Create a new SimCache instance with a given capacity.

pub fn write_best_to(&self, buf: &mut [MaybeUninit<(u128, SimItem)>]) -> usize

Fill a buffer with up to its capacity

pub fn read_best(&self, n: usize) -> Vec<(u128, SimItem)>

Get an iterator over the best items in the cache.

pub async fn read_best_valid<S, S2>( &self, n: usize, source: &S, host_source: &S2, ) -> Result<Vec<(u128, SimItem)>, Box<dyn Error>>
where S: StateSource, S2: StateSource,

Get up to the n best items in the cache that pass preflight validity checks (nonce and initial fee). The returned vector may be smaller than n if not enough valid items are found.

This will additionally remove items that can never be valid from the cache.

The state sources are used to validate the items against the current nonce and balance, to prevent simulating invalid items.

pub fn len(&self) -> usize

Get the number of items in the cache.

pub fn is_empty(&self) -> bool

True if the cache is empty.

pub fn get(&self, cache_rank: u128) -> Option<SimItem>

Get an item by key.

pub fn remove(&self, cache_rank: u128) -> Option<SimItem>

Remove an item by key.

pub fn remove_and_disallow(&self, cache_rank: u128) -> Option<SimItem>

Remove an item by key, and prevent it from being re-added for a while.

pub fn add_bundle( &self, bundle: SignetEthBundle, basefee: u64, ) -> Result<(), CacheError>

Add a bundle to the cache.

pub fn add_bundles<I, Item>(&self, item: I, basefee: u64)
where I: IntoIterator<Item = Item>, Item: Into<RecoveredBundle>,

Add an iterator of bundles to the cache. This locks the cache only once

Bundles added should have a valid replacement UUID. Bundles without a replacement UUID will be skipped.

pub fn add_tx(&self, tx: Recovered<TxEnvelope>, basefee: u64)

Add a transaction to the cache.

pub fn add_txs<I>(&self, item: I, basefee: u64)
where I: IntoIterator<Item = Recovered<TxEnvelope>>,

Add an iterator of transactions to the cache. This locks the cache only once

pub fn clean(&self, block_number: u64, block_timestamp: u64)

Clean the cache by removing bundles that are not valid in the current block.

pub fn clear(&self)

Clear the cache.