pub struct SimOutcomeWithCache {
pub cache_rank: u128,
pub score: U256,
pub gas_used: u64,
pub host_gas_used: u64,
pub rollup_cache: Cache,
pub host_cache: Cache,
pub bundle_fills: AggregateFills,
pub bundle_orders: AggregateOrders,
}Expand description
A simulation outcome that includes the score, gas used, and a cache of state changes.
Fields
cache_rank: u128The key for the item in the SimCache.
score: U256The score of the simulation, a U256 value that represents the
increase in the beneficiary’s balance.
gas_used: u64The total amount of gas used by the simulation.
host_gas_used: u64The total amount of host gas used by the simulation.
rollup_cache: CacheThe result of the simulation, a Cache containing state changes that
can be applied.
host_cache: CacheThe result of the bundle host simulation a Cache containing state
changes that can be applied.
bundle_fills: AggregateFillsThe aggregate fills after simulation.
bundle_orders: AggregateOrdersThe aggregate orders after simulation.