pub type SimDb<Db> = CacheOnWrite<InnerDb<Db>>;Expand description
A type alias for the database used in the simulation.
Aliased Type
pub struct SimDb<Db> { /* private fields */ }pub type SimDb<Db> = CacheOnWrite<InnerDb<Db>>;A type alias for the database used in the simulation.
pub struct SimDb<Db> { /* private fields */ }