Signet Sim
A simple parallelized transaction simulation library.
Structs
- Acct
Info - Account information including nonce and balance. This is partially modeled
after
revm::AccountInfo, but only includes the fields we care about. - Block
Build - Builds a single block by repeatedly invoking
SimEnv. - Built
Block - A block that has been built by the simulator.
- HostEnv
- A host simulation environment.
- Provider
State Source - A wrapper that implements
StateSourcefor any alloyProvider. - Rollup
Env - A rollup simulation environment.
- Shared
SimEnv - A simulation environment.
- SimCache
- A cache for the simulator.
- SimEnv
- A simulation environment.
- SimOutcome
With Cache - A simulation outcome that includes the score, gas used, and a cache of state changes.
Enums
- Cache
Error - Possible errors that can occur when using the cache.
- SimIdentifier
- A simulation cache item identifier.
- SimItem
- An item that can be simulated, wrapped in an Arc for cheap cloning.
- SimItem
Validity - The validity status of a simulation item.
Traits
- State
Source - A source for nonce and balance information. Exists to simplify type bounds in various places.
Functions
- check_
bundle_ tx_ list - Check a list of bundle transactions for validity against a state source.
Type Aliases
- InnerDb
- A type alias for the database underlying the simulation.
- SimDb
- A type alias for the database used in the simulation.
- Time
Limited - A time-limited layered inspector.