Crate signet_sim

Signet Sim

A simple parallelized transaction simulation library.

Structs

BlockBuild
Builds a single block by repeatedly invoking SimEnv.
BuiltBlock
A block that has been built by the simulator.
SharedSimEnv
A simulation environment.
SimCache
A cache for the simulator.
SimEnv
A simulation environment.
SimOutcomeWithCache
A simulation outcome that includes the score, gas used, and a cache of state changes.

Enums

SimItem
An item that can be simulated.

Type Aliases

InnerDb
A type alias for the database underlying the simulation.
SimDb
A type alias for the database used in the simulation.