Signet Sim
A simple parallelized transaction simulation library.
Structs
- Block
Build - Builds a single block by repeatedly invoking
SimEnv. - Built
Block - A block that has been built by the simulator.
- Shared
SimEnv - A simulation environment.
- SimCache
- A cache for the simulator.
- SimEnv
- A simulation environment.
- SimOutcome
With Cache - A simulation outcome that includes the score, gas used, and a cache of state changes.
Enums
- SimItem
- An item that can be simulated.