pub struct SimCache { /* private fields */ }Expand description
A cache for the simulator.
This cache is used to store the items that are being simulated.
Implementations
Sourceimpl SimCache
impl SimCache
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a new SimCache instance with a given capacity.
Sourcepub fn write_best_to(&self, buf: &mut [MaybeUninit<(u128, SimItem)>]) -> usize
pub fn write_best_to(&self, buf: &mut [MaybeUninit<(u128, SimItem)>]) -> usize
Fill a buffer with up to its capacity
Sourcepub fn read_best(&self, n: usize) -> Vec<(u128, SimItem)>
pub fn read_best(&self, n: usize) -> Vec<(u128, SimItem)>
Get an iterator over the best items in the cache.
Sourcepub async fn read_best_valid<S, S2>(
&self,
n: usize,
source: &S,
host_source: &S2,
) -> Result<Vec<(u128, SimItem)>, Box<dyn Error>>where
S: StateSource,
S2: StateSource,
pub async fn read_best_valid<S, S2>(
&self,
n: usize,
source: &S,
host_source: &S2,
) -> Result<Vec<(u128, SimItem)>, Box<dyn Error>>where
S: StateSource,
S2: StateSource,
Get up to the n best items in the cache that pass preflight validity
checks (nonce and initial fee). The returned vector may be smaller than
n if not enough valid items are found.
This will additionally remove items that can never be valid from the cache.
The state sources are used to validate the items against the current nonce and balance, to prevent simulating invalid items.
Sourcepub fn remove_and_disallow(&self, cache_rank: u128) -> Option<SimItem>
pub fn remove_and_disallow(&self, cache_rank: u128) -> Option<SimItem>
Remove an item by key, and prevent it from being re-added for a while.
Sourcepub fn add_bundle(
&self,
bundle: SignetEthBundle,
basefee: u64,
) -> Result<(), CacheError>
pub fn add_bundle( &self, bundle: SignetEthBundle, basefee: u64, ) -> Result<(), CacheError>
Add a bundle to the cache.
Sourcepub fn add_bundles<I, Item>(&self, item: I, basefee: u64)
pub fn add_bundles<I, Item>(&self, item: I, basefee: u64)
Add an iterator of bundles to the cache. This locks the cache only once
Bundles added should have a valid replacement UUID. Bundles without a replacement UUID will be skipped.
Sourcepub fn add_tx(&self, tx: Recovered<TxEnvelope>, basefee: u64)
pub fn add_tx(&self, tx: Recovered<TxEnvelope>, basefee: u64)
Add a transaction to the cache.
Sourcepub fn add_txs<I>(&self, item: I, basefee: u64)
pub fn add_txs<I>(&self, item: I, basefee: u64)
Add an iterator of transactions to the cache. This locks the cache only once